"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const index_1 = __importDefault(require("./index"));
describe("SecureStore", () => {
    let ss;
    const tests = [
        {
            desc: 'get something that does not exist',
            run: () => __awaiter(void 0, void 0, void 0, function* () {
                const res = yield ss.get('blahblah');
                (0, chai_1.expect)(res).to.eql(null);
            })
        },
        {
            desc: 'save string',
            run: () => __awaiter(void 0, void 0, void 0, function* () {
                yield ss.save('foo', 'hallo');
            })
        },
        {
            desc: 'get string',
            run: () => __awaiter(void 0, void 0, void 0, function* () {
                const res = yield ss.get('foo');
                (0, chai_1.expect)(typeof res).to.eql('string');
                (0, chai_1.expect)(res).to.eql('hallo');
            })
        },
        {
            desc: 'save object',
            run: () => __awaiter(void 0, void 0, void 0, function* () {
                yield ss.save('foo', { bar: 'baz', wang: 'bang' });
            })
        },
        {
            desc: 'get object',
            run: () => __awaiter(void 0, void 0, void 0, function* () {
                const res = yield ss.get('foo');
                (0, chai_1.expect)(typeof res).to.eql('object');
                (0, chai_1.expect)(res).to.eql({ bar: 'baz', wang: 'bang' });
            })
        }
    ];
    describe("connect with URL", () => {
        beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
            ss = new index_1.default('secure-store-redis-tests', '823HD8DG26JA0LK1239Hgb651TWfs0j1', {
                redis: {
                    url: 'redis://127.0.0.1:6379'
                }
            });
        }));
        for (const test of tests) {
            it(test.desc, test.run);
        }
        it('quit', () => __awaiter(void 0, void 0, void 0, function* () {
            yield ss.quit();
        }));
        it('disconnect', () => __awaiter(void 0, void 0, void 0, function* () {
            yield ss.disconnect();
        }));
    });
    // {
    //       desc: 'new scope',
    //       run: async () => {
    //         env.mod2 = new env.Mod('secure-store-redis-tests', 'idontknowthekeyidontknowthekey12', {
    //           host: '127.0.0.1',
    //           port: 6379
    //         });
    //         await env.mod2.init();
    //         test.assertTypeAnd(env.mod2, 'object');
    //         test.assertTypeAnd(env.mod2.get, 'function');
    //         test.assertType(env.mod2.save, 'function');
    //       }
    //     },
    //
    //
    //     {
    //       desc: 'get (wrong secret)',
    //       run: () => {
    //         const res = env.mod2.get('foo');
    //         expect(res).to.eql(null);
    //       }
    //     },
    //
    //     {
    //       desc: 'save complex object',
    //       run: async () => {
    //         env.complexObj = {
    //           foo: 'bar',
    //           bad: 'obj',
    //           this: true,
    //           me: {
    //             o: {
    //               me: {
    //                 o: [true, false, true, null, 'this', 'that', true, 9]
    //               }
    //             }
    //           }
    //         };
    //         await env.mod2.save('complex', env.complexObj);
    //         test.done();
    //       }
    //     },
    //
    //     {
    //       desc: 'get complex object',
    //       run: async () => {
    //         const res = await env.mod2.get('complex');
    //         test.assertTypeAnd(res, 'object');
    //         test.assert(res, env.complexObj);
    //       }
    //     },
});
//# sourceMappingURL=/index.test.js.map